#include <sta/bus/spi/device.hpp>

#include <sta/debug/assert.hpp>


namespace sta
{
    SPIDevice::SPIDevice(SPI * intf, GpioPin * csPin)
        : Device{intf}, intf_{intf}, csPin_{csPin}
    {
        STA_ASSERT(intf != nullptr);
        STA_ASSERT(csPin != nullptr);
    }

    bool SPIDevice::transfer(const uint8_t * txBuffer, uint8_t * rxBuffer, size_t size, uint32_t timeout /* = STA_MAX_TIMEOUT */)
	{
		// If these asserts fail, the user either forgot to call _beginTransmission()_ or the mutex acquision failed.
        STA_ASSERT(intf_->isAcquired());

        // Check if the user passed a null pointer as a buffer.
		STA_ASSERT(txBuffer != nullptr);
		STA_ASSERT(rxBuffer != nullptr);

		intf_->transfer(txBuffer, rxBuffer, size, timeout);
	}

    const SPISettings & SPIDevice::settings() const
    {
        return intf_->settings();
    }

    void SPIDevice::select()
    {
        csPin_->setLow();
    }

    void SPIDevice::deselect()
    {
        csPin_->setHigh();
    }
} // namespace sta
